@@ -144,6 +144,8 @@
 #include "unaryexpression.h"
 #include "binaryexpression.h"
 #include "expressionoperators.h"
+#include "skelitemtype.h"
+// #include "typeenv.h"
 
 //#define YYERROR_VERBOSE
 
@@ -152,6 +154,15 @@ int line = 1 ;
 extern int yylex() ;
 extern FILE *yyin ;
 
+/*
+
+THIS SEEMS TO BE USELESS FOR NOW
+
+static const skelitem_type checkType(const std::string &ide, const skelitem_type &type);
+
+static TypeEnv typeEnv;
+*/
+
 
 
 /* Enabling traces.  */
@@ -174,7 +185,7 @@ extern FILE *yyin ;
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 46 "parser.yy"
+#line 57 "parser.yy"
 {
   int tok ; /* command */
   char * string ; /* string : id, ... */
@@ -189,11 +200,9 @@ typedef union YYSTYPE
   class Expression *expression;
   class UnaryExpression *unaryexpression;
   class BinaryExpression *binaryexpression;
-
-  skelitem_type skel_item_type;
 }
 /* Line 187 of yacc.c.  */
-#line 197 "parser.cc"
+#line 206 "parser.cc"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -218,7 +227,7 @@ typedef struct YYLTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 222 "parser.cc"
+#line 231 "parser.cc"
 
 #ifdef short
 # undef short
@@ -516,10 +525,10 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    84,    84,    90,    95,   102,   103,   104,   107,   108,
-     111,   117,   122,   127,   136,   139,   143,   149,   153,   157,
-     163,   166,   167,   169,   173,   174,   178,   183,   188,   190,
-     192,   194,   195
+       0,    93,    93,    99,   104,   111,   112,   113,   116,   117,
+     120,   126,   132,   138,   148,   151,   155,   161,   165,   169,
+     175,   178,   179,   181,   185,   186,   190,   196,   202,   204,
+     206,   208,   209
 };
 #endif
 
@@ -1476,14 +1485,14 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 85 "parser.yy"
+#line 94 "parser.yy"
     {
          skel_items = (yyvsp[(1) - (1)].skelitems);
        }
     break;
 
   case 3:
-#line 91 "parser.yy"
+#line 100 "parser.yy"
     {
          (yyval.skelitems) = new SkelItems;
          (yyval.skelitems)->add_item ((yyvsp[(1) - (1)].skelitemstruct));
@@ -1491,7 +1500,7 @@ yyreduce:
     break;
 
   case 4:
-#line 96 "parser.yy"
+#line 105 "parser.yy"
     {
          (yyvsp[(1) - (2)].skelitems)->add_item ((yyvsp[(2) - (2)].skelitemstruct));
          (yyval.skelitems) = (yyvsp[(1) - (2)].skelitems);
@@ -1499,157 +1508,162 @@ yyreduce:
     break;
 
   case 5:
-#line 102 "parser.yy"
+#line 111 "parser.yy"
     { (yyval.skelitemstruct) = (yyvsp[(1) - (1)].normaltext); }
     break;
 
   case 6:
-#line 103 "parser.yy"
+#line 112 "parser.yy"
     { (yyval.skelitemstruct) = (yyvsp[(1) - (1)].varitem); }
     break;
 
   case 7:
-#line 104 "parser.yy"
+#line 113 "parser.yy"
     { (yyval.skelitemstruct) = (yyvsp[(1) - (1)].ifstruct); }
     break;
 
   case 8:
-#line 107 "parser.yy"
+#line 116 "parser.yy"
     { (yyval.skelitems) = (yyvsp[(1) - (1)].skelitems); }
     break;
 
   case 9:
-#line 108 "parser.yy"
+#line 117 "parser.yy"
     { (yyval.skelitems) = new SkelItems; }
     break;
 
   case 10:
-#line 112 "parser.yy"
+#line 121 "parser.yy"
     {
                (yyval.normaltext) = skel_factory->createNormalText ((yyvsp[(1) - (1)].string));
              }
     break;
 
   case 11:
-#line 118 "parser.yy"
+#line 127 "parser.yy"
     {
+             // const skelitem_type &type = checkType($2, "");
              (yyval.varitem) = skel_factory->createVarItem ((yyvsp[(2) - (3)].string), STRING_TYPE);
              (yyval.varitem)->setInfo((yylsp[(2) - (3)]).first_line);
            }
     break;
 
   case 12:
-#line 123 "parser.yy"
+#line 133 "parser.yy"
     {
-             (yyval.varitem) = skel_factory->createVarItem ((yyvsp[(2) - (5)].string), (yyvsp[(4) - (5)].skel_item_type));
+             //checkType($2, $4);
+             (yyval.varitem) = skel_factory->createVarItem ((yyvsp[(2) - (5)].string), (yyvsp[(4) - (5)].string));
              (yyval.varitem)->setInfo((yylsp[(2) - (5)]).first_line);
            }
     break;
 
   case 13:
-#line 128 "parser.yy"
+#line 139 "parser.yy"
     {
+             //checkType($2, $4);
              SkelItemOptions options;
              options.iteration = (yyvsp[(8) - (10)].boolean);
-             (yyval.varitem) = skel_factory->createVarItem ((yyvsp[(2) - (10)].string), (yyvsp[(4) - (10)].skel_item_type), options);
+             (yyval.varitem) = skel_factory->createVarItem ((yyvsp[(2) - (10)].string), (yyvsp[(4) - (10)].string), options);
              (yyval.varitem)->setInfo((yylsp[(2) - (10)]).first_line);
            }
     break;
 
   case 15:
-#line 140 "parser.yy"
+#line 152 "parser.yy"
     {
               (yyval.ifstruct) = new IfStruct((yyvsp[(2) - (5)].expression), (yyvsp[(4) - (5)].skelitems), 0);
            }
     break;
 
   case 16:
-#line 144 "parser.yy"
+#line 156 "parser.yy"
     {
               (yyval.ifstruct) = new IfStruct((yyvsp[(2) - (5)].expression), (yyvsp[(4) - (5)].skelitems), (yyvsp[(5) - (5)].ifstruct));
            }
     break;
 
   case 17:
-#line 150 "parser.yy"
+#line 162 "parser.yy"
     {
                (yyval.ifstruct) = new IfStruct(0, (yyvsp[(2) - (3)].skelitems));
              }
     break;
 
   case 18:
-#line 154 "parser.yy"
+#line 166 "parser.yy"
     {
                (yyval.ifstruct) = new IfStruct((yyvsp[(2) - (5)].expression), (yyvsp[(4) - (5)].skelitems), 0);
              }
     break;
 
   case 19:
-#line 158 "parser.yy"
+#line 170 "parser.yy"
     {
                (yyval.ifstruct) = new IfStruct((yyvsp[(2) - (5)].expression), (yyvsp[(4) - (5)].skelitems), (yyvsp[(5) - (5)].ifstruct));
              }
     break;
 
   case 22:
-#line 168 "parser.yy"
+#line 180 "parser.yy"
     { (yyval.expression) = new BinaryExpression( (yyvsp[(1) - (3)].expression)->getText() + " " + ANDOP + " " + (yyvsp[(3) - (3)].expression)->getText(), ANDOP, (yyvsp[(1) - (3)].expression), (yyvsp[(3) - (3)].expression)) ; }
     break;
 
   case 23:
-#line 170 "parser.yy"
+#line 182 "parser.yy"
     { (yyval.expression) = new BinaryExpression( (yyvsp[(1) - (3)].expression)->getText() + " " + OROP + " " + (yyvsp[(3) - (3)].expression)->getText(), OROP, (yyvsp[(1) - (3)].expression), (yyvsp[(3) - (3)].expression)) ; }
     break;
 
   case 25:
-#line 175 "parser.yy"
+#line 187 "parser.yy"
     { (yyval.expression) = new BinaryExpression( (yyvsp[(1) - (3)].expression)->getText() + " " + (yyvsp[(2) - (3)].string) + " " + (yyvsp[(3) - (3)].expression)->getText(), (yyvsp[(2) - (3)].string), (yyvsp[(1) - (3)].expression), (yyvsp[(3) - (3)].expression)) ; }
     break;
 
   case 26:
-#line 179 "parser.yy"
+#line 191 "parser.yy"
     {
+          	   // const skelitem_type &type = checkType($1, "");
                (yyval.expression) = new Expression((yyvsp[(1) - (1)].string));
                (yyval.expression)->setInfo((yylsp[(1) - (1)]).first_line);
           }
     break;
 
   case 27:
-#line 184 "parser.yy"
+#line 197 "parser.yy"
     {
-               (yyval.expression) = new Expression((yyvsp[(1) - (3)].string), (yyvsp[(3) - (3)].skel_item_type));
+          	   // checkType($1, $3);
+               (yyval.expression) = new Expression((yyvsp[(1) - (3)].string), (yyvsp[(3) - (3)].string));
                (yyval.expression)->setInfo((yylsp[(1) - (3)]).first_line);
           }
     break;
 
   case 28:
-#line 189 "parser.yy"
+#line 203 "parser.yy"
     { (yyval.expression) = new Expression((yyvsp[(1) - (1)].string), STRING_TYPE); (yyval.expression)->setInfo((yylsp[(1) - (1)]).first_line); (yyval.expression)->setIsConst(true); }
     break;
 
   case 29:
-#line 191 "parser.yy"
+#line 205 "parser.yy"
     { (yyval.expression) = new Expression((yyvsp[(1) - (1)].string), INT_TYPE); (yyval.expression)->setInfo((yylsp[(1) - (1)]).first_line); (yyval.expression)->setIsConst(true); }
     break;
 
   case 30:
-#line 193 "parser.yy"
+#line 207 "parser.yy"
     { (yyval.expression) = new Expression((yyvsp[(1) - (1)].string), BOOL_TYPE); (yyval.expression)->setInfo((yylsp[(1) - (1)]).first_line); (yyval.expression)->setIsConst(true); }
     break;
 
   case 31:
-#line 194 "parser.yy"
+#line 208 "parser.yy"
     { (yyval.expression) = (yyvsp[(2) - (3)].expression); }
     break;
 
   case 32:
-#line 196 "parser.yy"
+#line 210 "parser.yy"
     { (yyval.expression) = new UnaryExpression(string() + NOTOP + " " + (yyvsp[(2) - (2)].expression)->getText(), NOTOP, (yyvsp[(2) - (2)].expression)); }
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1653 "parser.cc"
+#line 1667 "parser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1869,7 +1883,27 @@ yyreturn:
 }
 
 
-#line 199 "parser.yy"
+#line 213 "parser.yy"
 
 
+/*
+const skelitem_type checkType(const std::string &ide, const skelitem_type &type) {
+	// if no type is specified
+	if (type == "") {
+		if (!typeEnv.hasType(ide)) {
+			// it's the first time we see this ide, so we assign type string
+			return STRING_TYPE;
+		} else {
+			// we return the already assigned type
+			return typeEnv.getType(ide);
+		} 
+	}
+
+	if (!typeEnv.setType(ide, type)) {
+		yyerror(ide + " has already been assigned type " + typeEnv.getType(ide));
+	}
+	
+	return type;
+}
+*/
 
